@@ -92,16 +92,16 @@ class Events:
     def submit_string(self, text):
         return self.__reply_status_check(self.device.con.get(path="sendCommitString", args="str=" + urllib.parse.quote(text)))
 
-    def click(self, x, y):
-        return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + str(x) + "|" + str(y)))
+    def click(self, x, y, delay=0):
+        return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + str(x) + "|" + str(y) + "&delay=" + str(delay)))
 
-    def multi_click(self, points):
+    def multi_click(self, points, delay=0):
         args = ""
         for point in points:
             args += str(point[0]) + "|" + str(point[1])
             if points.index(point) != len(points) - 1:
                 args += ","
-        return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + args))
+        return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + args + "&delay=" + str(delay)))
 
     def swipe(self, x1, y1, x2, y2):
         return self.__reply_status_check(self.device.con.get(path="sendSlideEvent", args="sliders=" + str(x1) + "|" + str(y1) + "->" + str(x2) + "|" + str(y2)))
@@ -114,10 +114,12 @@ class Events:
                 args += ","
         return self.__reply_status_check(self.device.con.get(path="sendSlideEvent", args="sliders=" + args))
 
-    def back(self):
-        return self.__reply_status_check(self.device.con.get(path="sendBackKeyEvent"))
+    def back(self, delay=0):
+        return self.__reply_status_check(self.device.con.get(path="sendBackKeyEvent", args="delay=" + str(delay)))
 
-    def home(self, timeout=None):
+    def home(self, delay=0, timeout=None):
+        if delay > 0:
+            return self.__reply_status_check(self.device.con.get(path="sendHomeKeyEvent", args="delay=" + str(delay)))
         if not timeout:
             timeout = self.device.default_timeout
         if self.__reply_status_check(self.device.con.get(path="sendHomeKeyEvent")):
@@ -132,8 +134,8 @@ class Events:
                     self.device.con.get(path="sendHomeKeyEvent")
         return False
 
-    def menu(self):
-        return self.__reply_status_check(self.device.con.get(path="sendMenuKeyEvent"))
+    def menu(self, delay=0):
+        return self.__reply_status_check(self.device.con.get(path="sendMenuKeyEvent", args="delay=" + str(delay)))
 
     def volume_up(self, delay=0):
         return self.__reply_status_check(self.device.con.get(path="sendVolumeUpKeyEvent", args="delay=" + str(delay)))
