@@ -559,9 +559,9 @@ class Item:
         image = cv2.add(image, src2)
         return image
 
-    def click(self):
+    def click(self, delay=0):
         if self.node is not None:
-            self.device.click(self.__center_x_to_global, self.__center_y_to_global)
+            self.device.click(self.__center_x_to_global, self.__center_y_to_global, delay)
 
     def click_exist(self, timeout=None):
         if self.exist(timeout):
